# MDT PRINT SERVICE: Websocket Server for ESC/POS Printers

## Operating System Support
- Windows
- Linux
- macOs

## Installing on client PC
- Download last release
- Unzip
- Copy files from dist folder
- Put into some folder

### For Windows
- Run mdt_print_service.exe
- Run as startup, put shortcut mdt_print_service.exe.ink into Startup Folder

*In the /doc directory you can find a useful utility (TrayIt) that can hide the window of a running server.* 

### For Linux or macOs
- Run into terminal
```
php mdt_print_service.phar
```

### For Linux (run as daemon)
- copy mdt_print_service.service to /etc/systemd/system/mdt_print_service.service
- edit User, Group (don't run it as root), WorkingDirectory and ExecStart 
```
sudo systemctl daemon-reload
sudo systemctl enable mdt_print_service.service
sudo systemctl start mdt_print_service.service
```

## How To Use

### Back End
- See example at example/mdt-service-print-example/print.php

### Front End
```js
function printMe(data) {
	var socket = new WebSocket("ws://127.0.0.1:40213");
	socket.bufferType = "arraybuffer";
	socket.onerror = function (error) {
		alert("Error");
	};
	socket.onopen = function () {
		socket.send(data);
		socket.close(1000, "Work complete");
	};
}

/**
 * This setting use SMB / LPT port for windows
 * if you want to use other port
 * see https://github.com/mike42/escpos-php/tree/development/example/interface for example
 * and edit file json printer.config.json
 */ 
const printerName = 'POS58'; // You can change printerName dynamicly
const data = {printerConfig: null, rawData: null};
$.getJSON('printer.config.json', (config) => {
	console.log('file json: ', config);
	data.printerConfig = config;
	data.printerConfig.connector.params.dest = data.printerConfig.connector.params.dest + printerName;
	console.log('printerConfig: ', data.printerConfig);
});

function ajaxPrint(url) {
	$.ajax({
		url: 'print.php', // you can change url dynamicly
		method: 'post',
		success: (rawData) => {
			data.rawData = rawData;
			printMe(JSON.stringify(data));
		},
		error: (err) => {
			alert('Ajax Error');
		}
	});
}
```